﻿using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.ComponentModel;
using System.Data;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace DataGridXamarin
{
    public class ViewModel : INotifyPropertyChanged
    {
        private OrderInfoRepository orderRepository;
        private ObservableCollection<OrderInfo> ordersInfo;
        private int searchIndex = -1;
        public ViewModel()
        {
            orderRepository = new OrderInfoRepository();
            GenerateRows();
        }

        public int SearchIndex
        {
            get { return searchIndex; }
            set { searchIndex = value;
                RaisePropertyChanged("SearchIndex");
            }
        }
        public ObservableCollection<OrderInfo> OrdersInfo
        {
            get { return ordersInfo; }
            set
            {
                ordersInfo = value;
                RaisePropertyChanged("OrdersInfo");
            }
        }

        private void GenerateRows()
        {
            ordersInfo = orderRepository.GenerateOrders(); 
        }

        #region INotifyPropertyChanged

        public event PropertyChangedEventHandler PropertyChanged;

        private void RaisePropertyChanged(string name)
        {
            if (PropertyChanged != null)
                this.PropertyChanged(this,new PropertyChangedEventArgs(name));
        }

        #endregion
    }

    public class DatagridViewModel
    {
        #region Fields

        private ObservableCollection<object> contactsInfo;
        private Random random = new Random();
        public DataTable dt;
        #endregion

        #region Constructor

        public DatagridViewModel()
        {
            GenerateSource(100);
        }

        #endregion

        #region Properties

        public ObservableCollection<object> ContactsInfo
        {
            get { return contactsInfo; }
            set { this.contactsInfo = value; }
        }

        public List<OrderInfo> OrdersList { get; set; }

        #endregion

        #region ItemSource

        public void GenerateSource(int count)
        {
            contactsInfo = new ObservableCollection<object>();

            dt = new DataTable("OrderInfo");
            dt.Columns.Add("OrderID", typeof(Int32));
            dt.Columns.Add("Customer", typeof(string));
            dt.Columns.Add("ShipCity", typeof(string));
            dt.Columns.Add("CustomerID", typeof(string));

            //Data  
            for (int i = 0; i < count; i++)
            {
                dt.Rows.Add(i, CustomerNames[i], contactType[random.Next(0, 5)], random.Next(100, 400).ToString() + "-" + random.Next(500, 800).ToString() + "-" + random.Next(1000, 2000).ToString());
            }

            for (int i = 0; i < dt.Rows.Count; i++)
            {
                contactsInfo.Add(dt.Rows[i]);
            }

            OrdersList = (from DataRow dr in dt.Rows
                           select new OrderInfo()
                           {
                               OrderID = Convert.ToInt32(dr["OrderID"]),
                               Customer = dr["Customer"].ToString(),
                               ShipCity = dr["ShipCity"].ToString(),
                               CustomerID = dr["CustomerID"].ToString()
                           }).ToList();

        }

        string[] contactType = new string[]
        {
            "HOME",
            "WORK",
            "MOBILE",
            "OTHER",
            "BUSINESS"
        };

        string[] CustomerNames = new string[]
        {
            "Kyle",
            "Gina",
            "Irene",
            "Katie",
            "Michael",
            "Oscar",
            "Ralph",
            "Torrey",
            "William",
            "Bill",
            "Daniel",
            "Frank",
            "Brenda",
            "Danielle",
            "Fiona",
            "Howard",
            "Jack",
            "Larry",
            "Holly",
            "Jennifer",
            "Liz",
            "Pete",
            "Steve",
            "Vince",
            "Zeke",
            "Aiden",
            "Jackson",
            "Mason  ",
            "Liam   ",
            "Jacob  ",
            "Jayden ",
            "Ethan  ",
            "Noah   ",
            "Lucas  ",
            "Logan  ",
            "Caleb  ",
            "Caden  ",
            "Jack   ",
            "Ryan   ",
            "Connor ",
            "Michael",
            "Elijah ",
            "Brayden",
            "Benjamin",
            "Nicholas",
            "Alexander",
            "William",
            "Matthew",
            "James  ",
            "Landon ",
            "Nathan ",
            "Dylan  ",
            "Evan   ",
            "Luke   ",
            "Andrew ",
            "Gabriel",
            "Gavin  ",
            "Joshua ",
            "Owen   ",
            "Daniel ",
            "Carter ",
            "Tyler  ",
            "Cameron",
            "Christian",
            "Wyatt  ",
            "Henry  ",
            "Eli    ",
            "Joseph ",
            "Max    ",
            "Isaac  ",
            "Samuel ",
            "Anthony",
            "Grayson",
            "Zachary",
            "David  ",
            "Christopher",
            "John   ",
            "Isaiah ",
            "Levi   ",
            "Jonathan",
            "Oliver ",
            "Chase  ",
            "Cooper ",
            "Tristan",
            "Colton ",
            "Austin ",
            "Colin  ",
            "Charlie",
            "Dominic",
            "Parker ",
            "Hunter ",
            "Thomas ",
            "Alex   ",
            "Ian    ",
            "Jordan ",
            "Cole   ",
            "Julian ",
            "Aaron  ",
            "Carson ",
            "Miles  ",
            "Blake  ",
            "Brody  ",
            "Adam   ",
            "Sebastian",
            "Adrian ",
            "Nolan  ",
            "Sean   ",
            "Riley  ",
            "Bentley",
            "Xavier ",
            "Hayden ",
            "Jeremiah",
            "Jason  ",
            "Jake   ",
            "Asher  ",
            "Micah  ",
            "Jace   ",
            "Brandon",
            "Josiah ",
            "Hudson ",
            "Nathaniel",
            "Bryson ",
            "Ryder  ",
            "Justin ",
            "Bryce  ",
        };


        #endregion
    }
}
